/**
 * An exception specific to the XM package.
 *
 * @author <a href="http://www.marchal.com">Beno&#238;t Marchal</a>
 */

package org.ananas.xm;

import java.text.MessageFormat;

public class XMException
   extends Exception
{
   /**
    * exception object if XMException embeds another exception
    */
   protected Exception exception = null;

   /**
    * Creates an XMException.
    */
   public XMException()
   {
      super();
   }

   /**
    * Creates an XMException.
    * @param msg error message
    */
   public XMException(String msg)
   {
      super(msg);
   }

   /**
    * Creates an XMException. Uses MessageFormat.format() to construct
    * the error message.
    * @param pattern MessageFormat's pattern
    * @param arguments arguments for MessageFormat
    * @see java.text.MessageFormat
    */
   public XMException(String pattern,Object[] arguments)
   {
      super(MessageFormat.format(pattern,arguments));
   }

   /**
    * Creates an XMException.
    * @param e embedded exception
    */
   public XMException(Exception e)
   {
      this("{0}: {1}",new Object[] { e.getClass().getName(), e.getMessage() });
      exception = e;
   }

   /**
    * The embedded exception, if any.
    * @return embedded exception or null if none
    */
   public Exception getException()
   {
      return exception;
   }
}
